@@ -16,10 +16,24 @@
 #
 # Copyright 2018 Ledger SAS, written by Olivier Hériveaux
 
-
+from .stage import Stage
 from .corvus import Corvus
 from .m3fs import M3FS
 from .smc100 import SMC100
 from .autofocus import Autofocus
 from .vector import Vector
 from .tic import Tic, TicDirection
+from .cncrouter import CNCRouter, CNCStatus
+
+__all__ = [
+    "Stage",
+    "Corvus",
+    "M3FS",
+    "SMC100",
+    "Autofocus",
+    "Vector",
+    "Tic",
+    "TicDirection",
+    "CNCRouter",
+    "CNCStatus",
+]
